# hydra4

hydra4 is a Python library for decoding Hesai Pandar packets to NumPy arrays or PointCloud2 messages.

## Installation

To install hydra4, run the following command in your terminal:

```bash
pip install hydra4
```
